@@ -11,7 +11,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.cdk
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.34.0", __name__, "aws-kms@0.34.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.35.0", __name__, "aws-kms@0.35.0.jsii.tgz")
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasAttributes", jsii_struct_bases=[])
 class AliasAttributes(jsii.compat.TypedDict):
     """
@@ -87,43 +87,66 @@ class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
         jsii.create(CfnAlias, self, [scope, id, props])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, properties: typing.Any) -> typing.Mapping[str,typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
         Arguments:
-            properties: -
+            props: -
 
         Stability:
             experimental
         """
-        return jsii.invoke(self, "renderProperties", [properties])
+        return jsii.invoke(self, "renderProperties", [props])
 
     @classproperty
-    @jsii.member(jsii_name="resourceTypeName")
-    def RESOURCE_TYPE_NAME(cls) -> str:
+    @jsii.member(jsii_name="cfnResourceTypeName")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
         """The CloudFormation resource type name for this resource class.
 
         Stability:
             experimental
         """
-        return jsii.sget(cls, "resourceTypeName")
+        return jsii.sget(cls, "cfnResourceTypeName")
+
+    @property
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
+        """
+        Stability:
+            experimental
+        """
+        return jsii.get(self, "cfnProperties")
 
     @property
     @jsii.member(jsii_name="aliasName")
     def alias_name(self) -> str:
-        """
+        """``AWS::KMS::Alias.AliasName``.
+
+        See:
+            http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html#cfn-kms-alias-aliasname
         Stability:
             experimental
         """
         return jsii.get(self, "aliasName")
 
+    @alias_name.setter
+    def alias_name(self, value: str):
+        return jsii.set(self, "aliasName", value)
+
     @property
-    @jsii.member(jsii_name="propertyOverrides")
-    def property_overrides(self) -> "CfnAliasProps":
-        """
+    @jsii.member(jsii_name="targetKeyId")
+    def target_key_id(self) -> str:
+        """``AWS::KMS::Alias.TargetKeyId``.
+
+        See:
+            http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html#cfn-kms-alias-targetkeyid
         Stability:
             experimental
         """
-        return jsii.get(self, "propertyOverrides")
+        return jsii.get(self, "targetKeyId")
+
+    @target_key_id.setter
+    def target_key_id(self, value: str):
+        return jsii.set(self, "targetKeyId", value)
 
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.CfnAliasProps", jsii_struct_bases=[])
@@ -163,7 +186,7 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
     cloudformationResource:
         AWS::KMS::Key
     """
-    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, key_policy: typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.Token], description: typing.Optional[str]=None, enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.Token]]]=None, enable_key_rotation: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.Token]]]=None, key_usage: typing.Optional[str]=None, pending_window_in_days: typing.Optional[typing.Union[typing.Optional[jsii.Number], typing.Optional[aws_cdk.cdk.Token]]]=None, tags: typing.Optional[typing.List[aws_cdk.cdk.CfnTag]]=None) -> None:
+    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, key_policy: typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.IResolvable], description: typing.Optional[str]=None, enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]=None, enable_key_rotation: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]=None, key_usage: typing.Optional[str]=None, pending_window_in_days: typing.Optional[jsii.Number]=None, tags: typing.Optional[typing.List[aws_cdk.cdk.CfnTag]]=None) -> None:
         """Create a new ``AWS::KMS::Key``.
 
         Arguments:
@@ -204,70 +227,154 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
         jsii.create(CfnKey, self, [scope, id, props])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, properties: typing.Any) -> typing.Mapping[str,typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
         Arguments:
-            properties: -
+            props: -
 
         Stability:
             experimental
         """
-        return jsii.invoke(self, "renderProperties", [properties])
+        return jsii.invoke(self, "renderProperties", [props])
 
     @classproperty
-    @jsii.member(jsii_name="resourceTypeName")
-    def RESOURCE_TYPE_NAME(cls) -> str:
+    @jsii.member(jsii_name="cfnResourceTypeName")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
         """The CloudFormation resource type name for this resource class.
 
         Stability:
             experimental
         """
-        return jsii.sget(cls, "resourceTypeName")
+        return jsii.sget(cls, "cfnResourceTypeName")
 
     @property
-    @jsii.member(jsii_name="keyArn")
-    def key_arn(self) -> str:
+    @jsii.member(jsii_name="attrArn")
+    def attr_arn(self) -> str:
         """
         Stability:
             experimental
         cloudformationAttribute:
             Arn
         """
-        return jsii.get(self, "keyArn")
+        return jsii.get(self, "attrArn")
 
     @property
-    @jsii.member(jsii_name="keyId")
-    def key_id(self) -> str:
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
         """
         Stability:
             experimental
         """
-        return jsii.get(self, "keyId")
-
-    @property
-    @jsii.member(jsii_name="propertyOverrides")
-    def property_overrides(self) -> "CfnKeyProps":
-        """
-        Stability:
-            experimental
-        """
-        return jsii.get(self, "propertyOverrides")
+        return jsii.get(self, "cfnProperties")
 
     @property
     @jsii.member(jsii_name="tags")
     def tags(self) -> aws_cdk.cdk.TagManager:
-        """The ``TagManager`` handles setting, removing and formatting tags.
-
-        Tags should be managed either passing them as properties during
-        initiation or by calling methods on this object. If both techniques are
-        used only the tags from the TagManager will be used. ``Tag`` (aspect)
-        will use the manager.
+        """``AWS::KMS::Key.Tags``.
 
+        See:
+            http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-tags
         Stability:
             experimental
         """
         return jsii.get(self, "tags")
 
+    @property
+    @jsii.member(jsii_name="keyPolicy")
+    def key_policy(self) -> typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.IResolvable]:
+        """``AWS::KMS::Key.KeyPolicy``.
+
+        See:
+            http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keypolicy
+        Stability:
+            experimental
+        """
+        return jsii.get(self, "keyPolicy")
+
+    @key_policy.setter
+    def key_policy(self, value: typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.IResolvable]):
+        return jsii.set(self, "keyPolicy", value)
+
+    @property
+    @jsii.member(jsii_name="description")
+    def description(self) -> typing.Optional[str]:
+        """``AWS::KMS::Key.Description``.
+
+        See:
+            http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-description
+        Stability:
+            experimental
+        """
+        return jsii.get(self, "description")
+
+    @description.setter
+    def description(self, value: typing.Optional[str]):
+        return jsii.set(self, "description", value)
+
+    @property
+    @jsii.member(jsii_name="enabled")
+    def enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]:
+        """``AWS::KMS::Key.Enabled``.
+
+        See:
+            http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-enabled
+        Stability:
+            experimental
+        """
+        return jsii.get(self, "enabled")
+
+    @enabled.setter
+    def enabled(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]):
+        return jsii.set(self, "enabled", value)
+
+    @property
+    @jsii.member(jsii_name="enableKeyRotation")
+    def enable_key_rotation(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]:
+        """``AWS::KMS::Key.EnableKeyRotation``.
+
+        See:
+            http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-enablekeyrotation
+        Stability:
+            experimental
+        """
+        return jsii.get(self, "enableKeyRotation")
+
+    @enable_key_rotation.setter
+    def enable_key_rotation(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]):
+        return jsii.set(self, "enableKeyRotation", value)
+
+    @property
+    @jsii.member(jsii_name="keyUsage")
+    def key_usage(self) -> typing.Optional[str]:
+        """``AWS::KMS::Key.KeyUsage``.
+
+        See:
+            http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keyusage
+        Stability:
+            experimental
+        """
+        return jsii.get(self, "keyUsage")
+
+    @key_usage.setter
+    def key_usage(self, value: typing.Optional[str]):
+        return jsii.set(self, "keyUsage", value)
+
+    @property
+    @jsii.member(jsii_name="pendingWindowInDays")
+    def pending_window_in_days(self) -> typing.Optional[jsii.Number]:
+        """``AWS::KMS::Key.PendingWindowInDays``.
+
+        See:
+            http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-pendingwindowindays
+        Stability:
+            experimental
+        """
+        return jsii.get(self, "pendingWindowInDays")
+
+    @pending_window_in_days.setter
+    def pending_window_in_days(self, value: typing.Optional[jsii.Number]):
+        return jsii.set(self, "pendingWindowInDays", value)
+
 
 @jsii.data_type_optionals(jsii_struct_bases=[])
 class _CfnKeyProps(jsii.compat.TypedDict, total=False):
@@ -279,7 +386,7 @@ class _CfnKeyProps(jsii.compat.TypedDict, total=False):
     Stability:
         experimental
     """
-    enabled: typing.Union[bool, aws_cdk.cdk.Token]
+    enabled: typing.Union[bool, aws_cdk.cdk.IResolvable]
     """``AWS::KMS::Key.Enabled``.
 
     See:
@@ -287,7 +394,7 @@ class _CfnKeyProps(jsii.compat.TypedDict, total=False):
     Stability:
         experimental
     """
-    enableKeyRotation: typing.Union[bool, aws_cdk.cdk.Token]
+    enableKeyRotation: typing.Union[bool, aws_cdk.cdk.IResolvable]
     """``AWS::KMS::Key.EnableKeyRotation``.
 
     See:
@@ -303,7 +410,7 @@ class _CfnKeyProps(jsii.compat.TypedDict, total=False):
     Stability:
         experimental
     """
-    pendingWindowInDays: typing.Union[jsii.Number, aws_cdk.cdk.Token]
+    pendingWindowInDays: jsii.Number
     """``AWS::KMS::Key.PendingWindowInDays``.
 
     See:
@@ -329,7 +436,7 @@ class CfnKeyProps(_CfnKeyProps):
     Stability:
         experimental
     """
-    keyPolicy: typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.Token]
+    keyPolicy: typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.IResolvable]
     """``AWS::KMS::Key.KeyPolicy``.
 
     See:
@@ -678,7 +785,7 @@ class Key(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws
     resource:
         AWS::KMS::Key
     """
-    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, retain: typing.Optional[bool]=None) -> None:
+    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, removal_policy: typing.Optional[aws_cdk.cdk.RemovalPolicy]=None) -> None:
         """
         Arguments:
             scope: -
@@ -688,7 +795,7 @@ class Key(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws
             enabled: Indicates whether the key is available for use. Default: - Key is enabled.
             enableKeyRotation: Indicates whether AWS KMS rotates the key. Default: false
             policy: Custom policy document to attach to the KMS key. Default: - A policy document with permissions for the account root to administer the key will be created.
-            retain: Whether the encryption key should be retained when it is removed from the Stack. This is useful when one wants to retain access to data that was encrypted with a key that is being retired. Default: true
+            removalPolicy: Whether the encryption key should be retained when it is removed from the Stack. This is useful when one wants to retain access to data that was encrypted with a key that is being retired. Default: RemovalPolicy.Retain
 
         Stability:
             experimental
@@ -707,8 +814,8 @@ class Key(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws
         if policy is not None:
             props["policy"] = policy
 
-        if retain is not None:
-            props["retain"] = retain
+        if removal_policy is not None:
+            props["removalPolicy"] = removal_policy
 
         jsii.create(Key, self, [scope, id, props])
 
@@ -880,14 +987,14 @@ class KeyProps(jsii.compat.TypedDict, total=False):
         experimental
     """
 
-    retain: bool
+    removalPolicy: aws_cdk.cdk.RemovalPolicy
     """Whether the encryption key should be retained when it is removed from the Stack.
 
     This is useful when one wants to
     retain access to data that was encrypted with a key that is being retired.
 
     Default:
-        true
+        RemovalPolicy.Retain
 
     Stability:
         experimental
@@ -920,15 +1027,6 @@ class ViaServicePrincipal(aws_cdk.aws_iam.PrincipalBase, metaclass=jsii.JSIIMeta
         """
         return jsii.get(self, "policyFragment")
 
-    @property
-    @jsii.member(jsii_name="serviceName")
-    def service_name(self) -> str:
-        """
-        Stability:
-            experimental
-        """
-        return jsii.get(self, "serviceName")
-
 
 __all__ = ["Alias", "AliasAttributes", "AliasProps", "CfnAlias", "CfnAliasProps", "CfnKey", "CfnKeyProps", "IAlias", "IKey", "Key", "KeyProps", "ViaServicePrincipal", "__jsii_assembly__"]
 
